"""Type stubs for rshogi.numpy — NumPy dtypes for packed SFEN data structures."""

from __future__ import annotations

from typing import Any


PackedSfen: Any
PackedSfenValue: Any

__all__ = ["PackedSfen", "PackedSfenValue"]



"""Core primitives for shogi."""

from rshogi._rshogi import Board, Move32, Move, to_move, normalize_usi_position, parse_usi_position

__all__ = ["Board", "Move32", "Move", "to_move", "parse_usi_position", "normalize_usi_position"]
